package com.bonus.material.settlement.service;

import java.util.List;
import com.bonus.material.settlement.domain.SltAgreementInfo;

/**
 * 结算信息Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface ISltAgreementInfoService {
    /**
     * 查询结算信息
     * 
     * @param id 结算信息主键
     * @return 结算信息
     */
    public SltAgreementInfo selectSltAgreementInfoById(Long id);

    /**
     * 查询结算信息列表
     * 
     * @param sltAgreementInfo 结算信息
     * @return 结算信息集合
     */
    public List<SltAgreementInfo> selectSltAgreementInfoList(SltAgreementInfo sltAgreementInfo);

    /**
     * 新增结算信息
     * 
     * @param sltAgreementInfo 结算信息
     * @return 结果
     */
    public int insertSltAgreementInfo(SltAgreementInfo sltAgreementInfo);

    /**
     * 修改结算信息
     * 
     * @param sltAgreementInfo 结算信息
     * @return 结果
     */
    public int updateSltAgreementInfo(SltAgreementInfo sltAgreementInfo);

    /**
     * 批量删除结算信息
     * 
     * @param ids 需要删除的结算信息主键集合
     * @return 结果
     */
    public int deleteSltAgreementInfoByIds(Long[] ids);

    /**
     * 删除结算信息信息
     * 
     * @param id 结算信息主键
     * @return 结果
     */
    public int deleteSltAgreementInfoById(Long id);
}
