package com.bonus.material.settlement.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.settlement.domain.SltAgreementInfo;
import com.bonus.material.settlement.service.ISltAgreementInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 结算信息Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "结算信息接口")
@RestController
@RequestMapping("/slt_agreement_info")
public class SltAgreementInfoController extends BaseController {
    @Autowired
    private ISltAgreementInfoService sltAgreementInfoService;

    /**
     * 查询结算信息列表
     */
    @ApiOperation(value = "查询结算信息列表")
    @RequiresPermissions("settlement:info:list")
    @GetMapping("/list")
    public TableDataInfo list(SltAgreementInfo sltAgreementInfo) {
        startPage();
        List<SltAgreementInfo> list = sltAgreementInfoService.selectSltAgreementInfoList(sltAgreementInfo);
        return getDataTable(list);
    }

    /**
     * 导出结算信息列表
     */
    @ApiOperation(value = "导出结算信息列表")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:info:export")
    @SysLog(title = "结算信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出结算信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SltAgreementInfo sltAgreementInfo) {
        List<SltAgreementInfo> list = sltAgreementInfoService.selectSltAgreementInfoList(sltAgreementInfo);
        ExcelUtil<SltAgreementInfo> util = new ExcelUtil<SltAgreementInfo>(SltAgreementInfo.class);
        util.exportExcel(response, list, "结算信息数据");
    }

    /**
     * 获取结算信息详细信息
     */
    @ApiOperation(value = "获取结算信息详细信息")
    @RequiresPermissions("settlement:info:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sltAgreementInfoService.selectSltAgreementInfoById(id));
    }

    /**
     * 新增结算信息
     */
    @ApiOperation(value = "新增结算信息")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:info:add")
    @SysLog(title = "结算信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增结算信息")
    @PostMapping
    public AjaxResult add(@RequestBody SltAgreementInfo sltAgreementInfo) {
        try {
            return toAjax(sltAgreementInfoService.insertSltAgreementInfo(sltAgreementInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改结算信息
     */
    @ApiOperation(value = "修改结算信息")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:info:edit")
    @SysLog(title = "结算信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改结算信息")
    @PutMapping
    public AjaxResult edit(@RequestBody SltAgreementInfo sltAgreementInfo) {
        try {
            return toAjax(sltAgreementInfoService.updateSltAgreementInfo(sltAgreementInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除结算信息
     */
    @ApiOperation(value = "删除结算信息")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:info:remove")
    @SysLog(title = "结算信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除结算信息")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sltAgreementInfoService.deleteSltAgreementInfoByIds(ids));
    }
}
